"""
A place to collect the various options that "can be passed to the
underlying engine." Just kidding, they're constants and you can't
change them. But this makes the user interface real simple.
"""


ABS_TOL = 1e-6
"""
The absolute tolerance used in all "are these numbers equal" and "is
this number less than (or equal to) that other number" tests. The CVXOPT
default is ``1e-7``, but loosening that a little reduces the number of
"unknown" solutions that we get during random testing. Whether or not it
improves the solubility of real problems is a question for the
philosophers.
"""


FLOAT_FORMAT = '%.7f'
"""
The default output format for floating point numbers. It has been
chosen to match the ``ABS_TOL``, in the sense that if ``x != y``,
then they would not appear different when printed.
"""


VERBOSE = False
"""
The underlying CVXOPT solver can output debug information, and I
guess, so could we. But we don't want to because it's ugly.
"""
